from random import randint, choice


def store(*args) -> str:
    """
        It is a function to generate a random store.

        :param: tuple int args: stores to generate a store

        :return: A random store between the present stores.
        :rtype: str

        :Example:
            >>> store(1, 10)
            >>> store(25)
    """
    if len(args) == 0:
        return f'por loja'
    elif len(args) <= 2:
        if isinstance(args, tuple):
            if len(args) == 1:
                return f'na loja {randint(1, args[0])}'
            args = list(args)
            args.sort()
            return f'na loja {randint(args[0], args[-1])}'
        else:
            return f'Insert a list or tuple of stores.'
    else:
        args = list(args)
        args.sort()
        return f'na loja {choice(args)}'



from random import choice


def date_partition(max_partition: int) -> str:
    """
        It is a function to generate a random date partition.

        :param: int max_partition: max partition to generate a date partition

        :return: A random date partition between the present date partitions.
        :rtype: str

        :Example:
            >>> date_partition(2)
            >>> date_partition(3)
    """
    date_partition = ['dia', 'semana', 'mês', 'trimestre', 'semestre', 'ano']
    return f'por {choice(date_partition[:max_partition])}'




from random import choice, randint

from pandas import DataFrame


def combobox_hierarchy(data: dict | DataFrame) -> str:
    """
        It is a function with generate a random combobox with hierarchy.

        :param data: A dict or DataFrame with the data.

        :return: A random combobox between the present combobox.
        :rtype: str

        :Example:
            >>> combobox_hierarchy({"Estado": ["SP", "SP", "SP", "SC", "SC", "SC"],
            >>> "Cidade": ["São Paulo", "Itatiba", "Campinas", "Chapecó", "Xaxim", "Xanxerê"]})
    """
    if isinstance(data, dict):
        df = DataFrame(data)
        check_hierarchy(df)
        first, second = set_choices(df)
        return f'{df.columns[0]} {first} e {df.columns[1]} {second}'
    elif isinstance(data, DataFrame):
        check_hierarchy(data)
        first, second = set_choices(data)
        return f'{data.columns[0]} {first} e {data.columns[1]} {second}'
    else:
        raise TypeError('The data must be a dict or a DataFrame')


def set_choices(df: DataFrame) -> tuple[str, str]:
    """
        It is a function to set the choices of the combobox.

        :param df: A DataFrame with the data.

        :return: A tuple with the choices.
        :rtype: tuple[str, str]

        :Example:
            >>> set_choices(df)
    """
    first = choice(df.iloc[:, 0])
    df = df[df.iloc[:, 0] == first]
    second = randint(0, len(df) - 1)
    return first, df.iloc[second, 1]


def check_hierarchy(df: DataFrame) -> bool:
    """
        It is a function to check if the DataFrame has hierarchy.

        :param df: A DataFrame with the data.

        :return: True if the DataFrame has hierarchy, False if not.
        :rtype: bool

        :Example:
            >>> check_hierarchy(df)
    """
    if len(df.iloc[:, 0]) != len(set(df.iloc[:, 0])):
        return True
    else:
        raise ValueError('The DataFrame must have hierarchy')



# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': 'src'}

packages = \
['random_filters',
 'random_filters.checkbox',
 'random_filters.combobox',
 'random_filters.date',
 'random_filters.date_partition',
 'random_filters.store']

package_data = \
{'': ['*']}

install_requires = \
['pandas>=1.4.0,<2.0.0', 'random>=1.0.0,<2.0.0']

setup_kwargs = {
    'name': 'random-filters',
    'version': '1.5.5',
    'description': 'A package for generating random filters',
    'long_description': '# Random filters: Python packaging for generate random filters to use in your project\n\n## Installation\n\n```bash\npip install random-filters\n```\n\n## Usage\n\n```python\nimport random_filters as rf\n\n# checkbox\nrf.checkbox()\n\n# combobox\nrf.combobox_hierarchy({"Estado": ["SP", "SP", "SP", "SC", "SC", "SC"],\n                       "Cidade": ["São Paulo", "Itatiba", "Campinas", "Chapecó", "Xaxim", "Xanxerê"]})\n\n# date\nrf.date(\'2019-01-01\', \'2019-12-31\')\n\n# date_partition\nrf.date_partition(2)\n\n# store\nrf.store(2)\n```\n\n## Contributing\nPull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.\n',
    'author': 'Renan',
    'author_email': 'renancavalcantercb@protonmail.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.10,<4.0',
}


setup(**setup_kwargs)



from random import randint, choice


def checkbox():
    """
        It is a function with the equivalent values of the present checkboxes in the question.

        :return: A random checkbox between the present checkboxes.
        :rtype: str

        :Example:
            >>> checkbox()
    """
    random_choice = randint(1, 2)
    if random_choice == 1:
        checkbox = ['almoco', 'jantar', 'final de semana', 'dia de semana']
        return choice(checkbox)
    else:
        return ''
